import { deepCopy, IParam, Singleton, RouteTool } from "@ibiz-core";
import { useRouter } from "vue-router";
const allViews= require('./views.json')

interface View extends IParam{
  codeName: string, 
  openMode ?: string,
}

interface Params extends IParam{
  context: any, 
  viewParams: any,
}

/**
 * 视图打开服务
 * @export
 * @class OpenViewService
 */
 export class OpenViewService extends Singleton{

  /**
   * 打开视图
   *
   * @param view 视图信息
   * @param params 相关参数
   */
  public openView(view: View, params: Params){
    // 获取详细视图信息
    let _view: any = allViews[view.codeName];
    if(!_view){
      console.error(`应用中不存在${view.codeName}视图`);
      return 
    }
    // 拷贝防污染，view的openMode覆盖配置的
    _view = deepCopy(_view);
    if(view.openMode){
      _view.openMode = view.openMode;
    }

    // 重定向视图走重定向逻辑，其他根据openMode打开
    if(_view.redirectView){
      this.openRedirectView(_view, params);
    }else{
      this.openByOpenMode(_view, params)
    }

  }

  /**
   * 根据打开方式打开视图
   *
   * @param view 视图信息
   * @param params 相关参数
   */
  public openByOpenMode(view: any, params: Params){
    const { openMode } = view;
    const { viewParams, context } = params
    // 路由打开视图
    if(openMode == 'INDEXVIEWTAB' || openMode == 'POPUPAPP'){
      // TODO 视图关系参数处理
      const router = useRouter();
      const routePath = RouteTool.buildUpRoutePath(view, context,viewParams);
      if(openMode == 'INDEXVIEWTAB'){
        router.push(routePath);
      }else{
        window.open('./#' + routePath, '_blank');
      }
    }else if(openMode == 'POPUPMODAL'){

    }else if(openMode.indexOf('DRAWER') !== -1){
      // TODO PMS上面抽屉DRAWER_TOP

    }else if(openMode == 'POPOVER'){
      // TODO 打开气泡卡片
    }else{
      console.error(`未支持${openMode}打开方式`);
    }

  }

  /**
   * 重定向视图处理
   *
   * @param view 视图信息
   * @param params 相关参数
   */
  public openRedirectView(view: any, params: Params){
    // TODO 重定向视图处理
  }
}